Skip to contents

Check prior predictions of the modskurt mean cover all possible shapes

Usage

check_prior_mskt(spec, use_subset = TRUE, n_draws = 50)

Arguments

spec

the modskurt model specification returned by `mskt_spec`

use_subset

whether to use specified subset or all data

n_draws

number of draws from the joint prior to use

Value

a ggplot object