Skip to contents

Check prior predictions of excess zero probabilities cover all possible relationships

Usage

check_prior_zero(spec, use_subset = TRUE, n_draws = 50)

Arguments

spec

the modskurt model specification returned by `mskt_spec`

use_subset

whether to use specified subset or all data

n_draws

number of draws from the joint prior to use

Plot prob zero for median mu_n? or just for a bell curve to show how it works?